@@ -2,6 +2,7 @@ from ._base import Base
 from ._categorical_mask import CategoricalMask
 from ._lower_bound import LowerBound
 from ._upper_bound import UpperBound
+from ._empty import Empty
 
 
-__all__ = ["Base", "CategoricalMask", "LowerBound", "UpperBound"]
+__all__ = ["Base", "CategoricalMask", "LowerBound", "UpperBound", "Empty"]
