@@ -18,6 +18,10 @@ class LowerBound(constraints.Base):
         self._scalar = len(bound.shape) == 0
         self._fn = torch.ge if allow_equal else torch.gt
 
+    @property
+    def dim(self) -> int:
+        return 0 if self._scalar else self._bound.shape[-1]
+
     @property
     def bound(self) -> torch.Tensor:
         """Bound."""
